@@ -34,4 +34,25 @@ fn build_device_boot(out_dir: &str) {
 
   println!("cargo:rustc-link-lib=static=oxide-boot-atmega4809");
   println!("cargo:rerun-if-changed=src/hal/atmega4809/boot.S");
+}
+
+#[cfg(all(feature="atmega328p",feature="bootable"))]
+fn build_device_boot(out_dir: &str) {
+  use std::path::Path;
+  use std::process::Command;
+
+  let _result = Command::new("avr-as")
+    .args(&["src/hal/atmega328p/boot.S",
+      "-mmcu=atmega328p", "-a",
+      "-o"])
+    .arg(&format!("{}/oxide-boot-atmega328p.o", out_dir))
+    .output().expect("Boot Assembly failed");
+
+  let _result = Command::new("avr-ar")
+    .args(&["crus", "liboxide-boot-atmega328p.a", "oxide-boot-atmega328p.o"])
+    .current_dir(&Path::new(out_dir))
+    .output().expect("Packaging boot library failed");
+
+  println!("cargo:rustc-link-lib=static=oxide-boot-atmega328p");
+  println!("cargo:rerun-if-changed=src/hal/atmega328p/boot.S");
 }
\ No newline at end of file
