@@ -10,10 +10,11 @@
 // Imports ===================================================================
 use avr_oxide::hal::concurrency;
 use avr_oxide::hal::concurrency::thread;
-use avr_oxide::deviceconsts::clock;
-use avr_oxide::hal::generic::cpu::ClockControl;
+use avr_oxide::hal::generic::cpu::{ClockControl, SleepControl};
 #[cfg(feature="alloc_ftr")]
 use avr_oxide::alloc;
+use avr_oxide::deviceconsts::clock;
+use avr_oxide::sleepctrl;
 
 // Declarations ==============================================================
 extern {
@@ -31,9 +32,15 @@ fn _oxide_boot() {
     // Inititalise the threading/concurrency system
     concurrency::internal::initialise();
 
+    // Reset the sleep mode
+    sleepctrl!().reset();
+
     // Set up any hardware-specific configuration
     #[cfg(feature="atmega4809")]
     avr_oxide::hal::atmega4809::cpu::clock().clk_per_prescaler(clock::MASTER_CLOCK_PRESCALER);
+    #[cfg(feature="atmega328p")]
+    avr_oxide::hal::atmega328p::cpu::clock().clk_per_prescaler(clock::MASTER_CLOCK_PRESCALER);
+
 
     // Create the supervisor
     let mut supervisor = avr_oxide::oxide::create_supervisor();
