@@ -59,20 +59,20 @@
 
 
 // Imports ===================================================================
-use crate::hal::generic::port::{Pin, PinMode, InterruptMode, PinIdentity};
-use crate::event::{EventSink, EventSource, OxideEvent, OxideEventEnvelope};
+use avr_oxide::hal::generic::port::{Pin, PinMode, InterruptMode, PinIdentity};
+use avr_oxide::event::{EventSink, EventSource, OxideEvent, OxideEventEnvelope};
 use core::marker::PhantomData;
 use core::ops::DerefMut;
 use core::cell::RefCell;
 use ufmt::derive::uDebug;
 use avr_oxide::devices::internal::StaticShareable;
 use oxide_macros::Persist;
-use crate::hal::generic::callback::IsrCallback;
+use avr_oxide::hal::generic::callback::IsrCallback;
 #[cfg(feature="alloc_ftr")]
-use crate::alloc::boxed::Box;
-use crate::devices::UsesPin;
-use crate::panic_if_none;
-use crate::util::OwnOrBorrowMut;
+use avr_oxide::alloc::boxed::Box;
+use avr_oxide::devices::UsesPin;
+use avr_oxide::panic_if_none;
+use avr_oxide::util::OwnOrBorrowMut;
 
 // Declarations ==============================================================
 
