@@ -38,11 +38,11 @@
 // Imports ===================================================================
 use core::any::Any;
 use core::cell::Cell;
-use crate::hal::generic::callback::IsrCallback;
-use crate::hal::generic::port::{InterruptMode, Pin, PinIsrCallback, PinMode};
-use crate::{isr_cb_invoke, panic_if_none};
-use crate::devices::UsesPin;
-use crate::util::OwnOrBorrowMut;
+use avr_oxide::hal::generic::callback::IsrCallback;
+use avr_oxide::hal::generic::port::{InterruptMode, Pin, PinIsrCallback, PinMode};
+use avr_oxide::{isr_cb_invoke, panic_if_none};
+use avr_oxide::devices::UsesPin;
+use avr_oxide::util::OwnOrBorrowMut;
 use avr_oxide::devices::internal::StaticShareable;
 
 // Declarations ==============================================================
