@@ -44,20 +44,20 @@
 
 
 // Imports ===================================================================
-use crate::hal::generic::serial::{SerialRxTx, ReadHandlerResult, SerialError, SerialPortMode, SerialPortIdentity, SerialWriteEventCallback, SerialReadEventCallback, SerialErrorEventCallback};
-use crate::event::{EventSink, EventSource, OxideEvent, OxideEventEnvelope};
+use avr_oxide::hal::generic::serial::{SerialRxTx, ReadHandlerResult, SerialError, SerialPortMode, SerialPortIdentity, SerialWriteEventCallback, SerialReadEventCallback, SerialErrorEventCallback};
+use avr_oxide::event::{EventSink, EventSource, OxideEvent, OxideEventEnvelope};
 use core::marker::PhantomData;
 use core::cell::RefCell;
 use core::ops::DerefMut;
 use ufmt::derive::uDebug;
 use avr_oxide::devices::internal::StaticShareable;
 use oxide_macros::Persist;
-use crate::alloc::boxed::Box;
-use crate::devices::Handle;
-use crate::hal::generic::callback::IsrCallback;
-use crate::hal::generic::port::{Pin, PinMode};
-use crate::panic_if_none;
-use crate::util::{BitField, BitIndex};
+use avr_oxide::alloc::boxed::Box;
+use avr_oxide::devices::Handle;
+use avr_oxide::hal::generic::callback::IsrCallback;
+use avr_oxide::hal::generic::port::{Pin, PinMode};
+use avr_oxide::panic_if_none;
+use avr_oxide::util::{BitField, BitIndex};
 
 // Declarations ===============================================================
 pub trait SerialCallback = FnMut(SerialPortIdentity, SerialState) -> ();
@@ -122,6 +122,7 @@ const TX_FLUSH_ON_EOL: BitIndex =  BitIndex::bit(0);
 const TX_CR_TO_CRLF:   BitIndex =  BitIndex::bit(1);
 const TX_LF_TO_CRLF:   BitIndex =  BitIndex::bit(2);
 const INTERACTIVE:     BitIndex =  BitIndex::bit(3);
+const ECHO:            BitIndex =  BitIndex::bit(4);
 
 /**
  * Configuration of various translation/usability options for the serial
@@ -133,6 +134,7 @@ const INTERACTIVE:     BitIndex =  BitIndex::bit(3);
  * | `cr_to_crlf`   | Translate sent CRs to CRLF |
  * | `lf_to_crlf`   | Translate sent LFs to CRLF |
  * | `interactive`  | This is an interactive terminal, reading from the device will automatically flush the transmit buffer first |
+ * | `echo`         | Echo all characters received back on the transmit line.  If interactive is set, will also flush after each. |
  */
 impl SerialOptions {
   /// Indicate that the device should automatically flush when an end-of-line
@@ -178,6 +180,18 @@ impl SerialOptions {
     self.is_set(INTERACTIVE)
   }
 
+  /// Indicate that we should echo received characters back.
+  /// If the device is also set to `interactive`, then we will flush() after
+  /// each echoed character as well.
+  pub fn set_echo(&mut self, flag: bool) {
+    self.set_or_clr(ECHO, flag)
+  }
+
+  /// True iff we should echo everything we receive back on transmit
+  pub fn echo(&self) -> bool {
+    self.is_set(ECHO)
+  }
+
   /// Clear all settings that result in the data being translated in any
   /// way (e.g. CR to CRLF type translations.)  Use this to ensure a serial
   /// port is 'clean' for sending/receiving binary data.
@@ -308,14 +322,14 @@ where
   }
 }
 
-impl<P,T,R,S> crate::io::Read for SerialPort<'_,P,T,R,S>
+impl<P,T,R,S> avr_oxide::io::Read for SerialPort<'_,P,T,R,S>
 where
   P: 'static + SerialRxTx,
   T: 'static + Pin,
   R: 'static + Pin,
   S: EventSink
 {
-  fn read(&mut self, buf: &mut [u8]) -> crate::io::Result<usize> {
+  fn read(&mut self, buf: &mut [u8]) -> avr_oxide::io::Result<usize> {
     let mut cnt = 0usize;
 
     if self.serial_options.interactive() {
@@ -326,6 +340,14 @@ where
       match self.port.try_read_u8() {
         Some(c) => {
           buf[cnt] = c;
+
+          if self.serial_options.echo() {
+            self.port.write_u8(c);
+            if self.serial_options.interactive() {
+              self.port.flush();
+            }
+          }
+
           cnt += 1;
         },
         None => {
@@ -338,14 +360,14 @@ where
   }
 }
 
-impl<P,T,R,S> crate::io::Write for SerialPort<'_,P,T,R,S>
+impl<P,T,R,S> avr_oxide::io::Write for SerialPort<'_,P,T,R,S>
 where
   P: 'static + SerialRxTx,
   T: 'static + Pin,
   R: 'static + Pin,
   S: EventSink
 {
-  fn write(&mut self, buf: &[u8]) -> crate::io::Result<usize> {
+  fn write(&mut self, buf: &[u8]) -> avr_oxide::io::Result<usize> {
     let cnt : usize = 0;
 
     for byte in buf {
@@ -384,7 +406,7 @@ where
     Ok(cnt)
   }
 
-  fn flush(&mut self) -> crate::io::Result<()> {
+  fn flush(&mut self) -> avr_oxide::io::Result<()> {
     self.port.flush();
     Ok(())
   }
@@ -400,35 +422,35 @@ impl<P,T,R,S> ufmt_write::uWrite for SerialPort<'_,P,T,R,S>
   type Error = core::convert::Infallible;
 
   fn write_str(&mut self, s: &str) -> Result<(), Self::Error> {
-    let _ignore = crate::io::Write::write(self, s.as_bytes());
+    let _ignore = avr_oxide::io::Write::write(self, s.as_bytes());
     Ok(())
   }
 }
 
-impl<P,T,R,S> crate::io::Write for Handle<SerialPort<'_,P,T,R,S>>
+impl<P,T,R,S> avr_oxide::io::Write for Handle<SerialPort<'_,P,T,R,S>>
 where
   P: 'static + SerialRxTx,
   T: 'static + Pin,
   R: 'static + Pin,
   S: EventSink
 {
-  fn write(&mut self, buf: &[u8]) -> crate::io::Result<usize> {
+  fn write(&mut self, buf: &[u8]) -> avr_oxide::io::Result<usize> {
     Handle::deref_mut(self).write(buf)
   }
 
-  fn flush(&mut self) -> crate::io::Result<()> {
+  fn flush(&mut self) -> avr_oxide::io::Result<()> {
     Handle::deref_mut(self).flush()
   }
 }
 
-impl<P,T,R,S> crate::io::Read for Handle<SerialPort<'_,P,T,R,S>>
+impl<P,T,R,S> avr_oxide::io::Read for Handle<SerialPort<'_,P,T,R,S>>
 where
   P: 'static + SerialRxTx,
   T: 'static + Pin,
   R: 'static + Pin,
   S: EventSink
 {
-  fn read(&mut self, buf: &mut [u8]) -> crate::io::Result<usize> {
+  fn read(&mut self, buf: &mut [u8]) -> avr_oxide::io::Result<usize> {
     Handle::deref_mut(self).read(buf)
   }
 }
