@@ -106,15 +106,15 @@ use core::marker::PhantomData;
 use core::cell::RefCell;
 use core::ops::DerefMut;
 use avr_oxide::devices::internal::StaticShareable;
-use crate::alloc::boxed::Box;
-use crate::devices::masterclock::{DelayCallback, DelayEvents};
-use crate::event::{EventSink, EventSource, OxideEvent, OxideEventEnvelope};
-use crate::hal::generic::timer::{RtcCalibration, RtcPrescaler, RtcSource, RtcTimerCalibration, TimerControl, TimerIsrCallback};
-use crate::hal::generic::timer::TimerMode::Periodic;
-use crate::panic_if_none;
-use crate::private::delayq::{DelayQueue, SimpleDelayQueue};
-use crate::util::OwnOrBorrowMut;
-use crate::time::Duration;
+use avr_oxide::alloc::boxed::Box;
+use avr_oxide::devices::masterclock::{DelayCallback, DelayEvents};
+use avr_oxide::event::{EventSink, EventSource, OxideEvent, OxideEventEnvelope};
+use avr_oxide::hal::generic::timer::{RtcCalibration, RtcPrescaler, RtcSource, RtcTimerCalibration, TimerControl, TimerIsrCallback};
+use avr_oxide::hal::generic::timer::TimerMode::Periodic;
+use avr_oxide::panic_if_none;
+use avr_oxide::private::delayq::{DelayQueue, SimpleDelayQueue};
+use avr_oxide::util::OwnOrBorrowMut;
+use avr_oxide::time::Duration;
 
 use super::masterclock::TickCallback;
 use super::masterclock::TickEvents;
@@ -198,14 +198,14 @@ where
 
   /// Return the total duration for which the clock has been running
   pub fn runtime(&self) -> Duration {
-    crate::hal::concurrency::interrupt::isolated(||{
+    avr_oxide::hal::concurrency::interrupt::isolated(||{
       self.running_time
     })
   }
 
   /// Return true iff the runtime counter has overflowed
   pub fn runtime_overflowed(&self) -> bool {
-    crate::hal::concurrency::interrupt::isolated(||{
+    avr_oxide::hal::concurrency::interrupt::isolated(||{
       self.running_time_overflow
     })
   }
@@ -213,7 +213,7 @@ where
   /// Clear the flag indicating that the runtime counter overflowed (until
   /// the next time...)
   pub fn clear_runtime_overflow(&mut self) {
-    crate::hal::concurrency::interrupt::isolated(||{
+    avr_oxide::hal::concurrency::interrupt::isolated(||{
       self.running_time_overflow = false
     })
   }
@@ -222,7 +222,7 @@ where
   /// counter overflows, we will set a flag so the recipient can know that
   /// but then we just keep on trucking.
   fn increment_running_time(&mut self, secs: u16) {
-    crate::hal::concurrency::interrupt::isolated(||{
+    avr_oxide::hal::concurrency::interrupt::isolated(||{
       match self.running_time.checked_add(Duration::from_secs(secs as u32)) {
         None => { // The addition would overflow
           self.running_time_overflow = true;
