@@ -21,7 +21,7 @@ pub struct PortmuxControl {
 
 // Code ======================================================================
 
-atmel_cpu_tpl!(super::ADDR_CPU,super::ADDR_CLKCTRL);
+atmel_cpu_tpl!(super::ADDR_CPU,super::ADDR_CLKCTRL,super::ADDR_SLPCTRL);
 
 /**
  * Obtain a reference to the CPU controller instance
@@ -33,3 +33,12 @@ macro_rules! cpu {
   }
 }
 
+/**
+ * Obtain a references to the Sleep controller instance
+ */
+#[macro_export]
+macro_rules! sleepctrl {
+  () => {
+    avr_oxide::hal::atmega4809::cpu::sleepctrl()
+  }
+}
\ No newline at end of file
