@@ -9,8 +9,8 @@
 // Imports ===================================================================
 
 // Declarations ==============================================================
-use crate::hal::generic::debugled::DebugLed;
-use crate::hal::generic::port::base::AtmelPortControl;
+use avr_oxide::hal::generic::debugled::DebugLed;
+use avr_oxide::hal::generic::port::base::AtmelPortControl;
 
 // Code ======================================================================
 pub struct PinE2DebugLed {}
@@ -18,7 +18,7 @@ pub struct PinE2DebugLed {}
 impl DebugLed for PinE2DebugLed {
   #[inline(always)]
   fn on() {
-    let porte = crate::hal::atmega4809::port::porte::instance();
+    let porte = avr_oxide::hal::atmega4809::port::porte::instance();
 
     porte.enable_output(2);
     porte.set_high(2);
@@ -26,7 +26,7 @@ impl DebugLed for PinE2DebugLed {
 
   #[inline(always)]
   fn off() {
-    let porte = crate::hal::atmega4809::port::porte::instance();
+    let porte = avr_oxide::hal::atmega4809::port::porte::instance();
 
     porte.enable_output(2);
     porte.set_low(2);
@@ -34,7 +34,7 @@ impl DebugLed for PinE2DebugLed {
 
   #[inline(always)]
   fn toggle() {
-    let porte = crate::hal::atmega4809::port::porte::instance();
+    let porte = avr_oxide::hal::atmega4809::port::porte::instance();
 
     porte.enable_output(2);
     porte.toggle(2);
@@ -46,7 +46,7 @@ pub struct PinB1DebugLed {}
 impl DebugLed for PinB1DebugLed {
   #[inline(always)]
   fn on() {
-    let portb = crate::hal::atmega4809::port::portb::instance();
+    let portb = avr_oxide::hal::atmega4809::port::portb::instance();
 
     portb.enable_output(1);
     portb.set_high(1);
@@ -54,7 +54,7 @@ impl DebugLed for PinB1DebugLed {
 
   #[inline(always)]
   fn off() {
-    let portb = crate::hal::atmega4809::port::portb::instance();
+    let portb = avr_oxide::hal::atmega4809::port::portb::instance();
 
     portb.enable_output(1);
     portb.set_low(1);
@@ -62,7 +62,7 @@ impl DebugLed for PinB1DebugLed {
 
   #[inline(always)]
   fn toggle() {
-    let portb = crate::hal::atmega4809::port::portb::instance();
+    let portb = avr_oxide::hal::atmega4809::port::portb::instance();
 
     portb.enable_output(1);
     portb.toggle(1);
