@@ -40,8 +40,8 @@ pub mod panicout {
 // Code ======================================================================
 #[cfg(feature="usart0")]
 pub mod usart0 {
-  use avr_oxide::{atmel_usart_tpl};
-  use avr_oxide::hal::generic::serial::base::usart::MuxControl;
+  use avr_oxide::{atmel_0series_usart_tpl};
+  use avr_oxide::hal::generic::serial::base::zeroseries::MuxControl;
   #[cfg(target_arch="avr")]
   use avr_oxide::hal::atmega4809::cpu::PortmuxControl;
 
@@ -78,9 +78,9 @@ pub mod usart0 {
     }
   }
 
-  atmel_usart_tpl!(super::super::ADDR_USART0,
+  atmel_0series_usart_tpl!(super::super::ADDR_USART0,
     avr_oxide::hal::generic::serial::SerialPortIdentity::Usart0,
-    SerialPortPins, 64,
+    avr_oxide::hal::generic::serial::base::zeroseries::AtmelUsart<SerialPortPins,64>,
     _ivr_usart0_rcx, _ivr_usart0_tcx, _ivr_usart0_dre);
 
 
@@ -88,8 +88,8 @@ pub mod usart0 {
 
 #[cfg(feature="usart1")]
 pub mod usart1 {
-  use avr_oxide::{atmel_usart_tpl};
-  use avr_oxide::hal::generic::serial::base::usart::MuxControl;
+  use avr_oxide::{atmel_0series_usart_tpl};
+  use avr_oxide::hal::generic::serial::base::zeroseries::MuxControl;
   #[cfg(target_arch="avr")]
   use avr_oxide::hal::atmega4809::cpu::PortmuxControl;
 
@@ -122,9 +122,9 @@ pub mod usart1 {
     }
   }
 
-  atmel_usart_tpl!(super::super::ADDR_USART1,
+  atmel_0series_usart_tpl!(super::super::ADDR_USART1,
     avr_oxide::hal::generic::serial::SerialPortIdentity::Usart1,
-    SerialPortPins, 64,
+    avr_oxide::hal::generic::serial::base::zeroseries::AtmelUsart<SerialPortPins,64>,
     _ivr_usart1_rcx, _ivr_usart1_tcx, _ivr_usart1_dre);
 
 
@@ -132,8 +132,8 @@ pub mod usart1 {
 
 #[cfg(feature="usart2")]
 pub mod usart2 {
-  use avr_oxide::{atmel_usart_tpl};
-  use avr_oxide::hal::generic::serial::base::usart::MuxControl;
+  use avr_oxide::{atmel_0series_usart_tpl};
+  use avr_oxide::hal::generic::serial::base::zeroseries::MuxControl;
   #[cfg(target_arch="avr")]
   use avr_oxide::hal::atmega4809::cpu::PortmuxControl;
 
@@ -166,9 +166,9 @@ pub mod usart2 {
     }
   }
 
-  atmel_usart_tpl!(super::super::ADDR_USART2,
+  atmel_0series_usart_tpl!(super::super::ADDR_USART2,
     avr_oxide::hal::generic::serial::SerialPortIdentity::Usart2,
-    SerialPortPins, 64,
+    avr_oxide::hal::generic::serial::base::zeroseries::AtmelUsart<SerialPortPins, 64>,
     _ivr_usart2_rcx, _ivr_usart2_tcx, _ivr_usart2_dre);
 
 
@@ -176,8 +176,8 @@ pub mod usart2 {
 
 #[cfg(feature="usart3")]
 pub mod usart3 {
-  use avr_oxide::{atmel_usart_tpl};
-  use avr_oxide::hal::generic::serial::base::usart::MuxControl;
+  use avr_oxide::{atmel_0series_usart_tpl};
+  use avr_oxide::hal::generic::serial::base::zeroseries::MuxControl;
   #[cfg(target_arch="avr")]
   use avr_oxide::hal::atmega4809::cpu::PortmuxControl;
 
@@ -211,8 +211,8 @@ pub mod usart3 {
     }
   }
 
-  atmel_usart_tpl!(super::super::ADDR_USART3,
+  atmel_0series_usart_tpl!(super::super::ADDR_USART3,
     avr_oxide::hal::generic::serial::SerialPortIdentity::Usart3,
-    SerialPortPins, 64,
+    avr_oxide::hal::generic::serial::base::zeroseries::AtmelUsart<SerialPortPins, 64>,
     _ivr_usart3_rcx, _ivr_usart3_tcx, _ivr_usart3_dre);
 }
