@@ -6,9 +6,9 @@
 //! ATmega4809-specific implementation of the AVR watchdog timer
 
 // Imports ===================================================================
-use crate::{atmel_watchdog_tpl};
+use avr_oxide::{atmel_watchdog_tpl};
 
 // Declarations ==============================================================
 
 // Code ======================================================================
-atmel_watchdog_tpl!(super::ADDR_WDT, crate::hal::atmega4809::cpu::instance());
\ No newline at end of file
+atmel_watchdog_tpl!(super::ADDR_WDT, avr_oxide::hal::atmega4809::cpu::instance());
\ No newline at end of file
