@@ -181,6 +181,7 @@ pub mod thread {
 
 pub mod interrupt {
   use avr_oxide::hal::generic::cpu::Cpu;
+  use avr_oxide::cpu;
 
   /**
    * Execute the given closure without interruptions
@@ -192,7 +193,7 @@ pub mod interrupt {
     unsafe {
       // Save the current sreg and then disable interrupts
       #[cfg(target_arch="avr")]
-      let sreg = avr_oxide::cpu!().read_sreg();
+      let sreg = cpu!().read_sreg();
 
       disable_interrupts();
 
@@ -200,7 +201,7 @@ pub mod interrupt {
 
       // Don't explicitly re-enable interrupts, rather we just restore sreg
       #[cfg(target_arch="avr")]
-      avr_oxide::cpu!().write_sreg(sreg);
+      cpu!().write_sreg(sreg);
 
       result
     }
@@ -210,16 +211,101 @@ pub mod interrupt {
    * Execute the given code within the context of an Interrupt Service Routine.
    */
   #[inline(always)]
-  pub(crate) fn isr<F,R>(f: F) -> R
+  pub(crate) fn isr<F>(f: F) -> ()
   where
-    F: FnOnce() -> R
+    F: FnOnce() -> (),
   {
-    // Actually does pretty much nothing at the moment, but keeping this around
-    // because it may be useful in the future
-    avr_oxide::hal::atmega4809::debugled::PinE2DebugLed::on();
-    let result = f();
-    avr_oxide::hal::atmega4809::debugled::PinE2DebugLed::off();
-    result
+    // @todo: OK, so this is quite clearly absolutely horrendous.
+    //        I need to find out exactly what code generation bug still
+    //        remains that LLVM isn't generating proper register saves
+    //        on interrupt service routines, and fix it.  Because obviously
+    //        saving and restoring every single register on every interrupt
+    //        is just painful.  On the other hand, it does make things
+    //        actually functional...
+    #[allow(deprecated)]
+    unsafe {
+      llvm_asm!("push r24" :::: "volatile");
+      #[cfg(feature="atmega4809")]
+      llvm_asm!("in r24,0x0F" :::: "volatile");
+      #[cfg(feature="atmega328p")]
+      llvm_asm!("in r24,0x3F" :::: "volatile");
+      llvm_asm!("push r24" :::: "volatile");
+
+      llvm_asm!("push r31" :::: "volatile");
+      llvm_asm!("push r30" :::: "volatile");
+      llvm_asm!("push r29" :::: "volatile");
+      llvm_asm!("push r28" :::: "volatile");
+      llvm_asm!("push r27" :::: "volatile");
+      llvm_asm!("push r26" :::: "volatile");
+      llvm_asm!("push r25" :::: "volatile");
+
+      llvm_asm!("push r23" :::: "volatile");
+      llvm_asm!("push r22" :::: "volatile");
+      llvm_asm!("push r21" :::: "volatile");
+      llvm_asm!("push r20" :::: "volatile");
+      llvm_asm!("push r19" :::: "volatile");
+      llvm_asm!("push r18" :::: "volatile");
+      llvm_asm!("push r17" :::: "volatile");
+      llvm_asm!("push r16" :::: "volatile");
+      llvm_asm!("push r15" :::: "volatile");
+      llvm_asm!("push r14" :::: "volatile");
+      llvm_asm!("push r13" :::: "volatile");
+      llvm_asm!("push r12" :::: "volatile");
+      llvm_asm!("push r11" :::: "volatile");
+      llvm_asm!("push r10" :::: "volatile");
+      llvm_asm!("push r9" :::: "volatile");
+      llvm_asm!("push r8" :::: "volatile");
+      llvm_asm!("push r7" :::: "volatile");
+      llvm_asm!("push r6" :::: "volatile");
+      llvm_asm!("push r5" :::: "volatile");
+      llvm_asm!("push r4" :::: "volatile");
+      llvm_asm!("push r3" :::: "volatile");
+      llvm_asm!("push r2" :::: "volatile");
+      llvm_asm!("push r1" :::: "volatile");
+      llvm_asm!("push r0" :::: "volatile");
+
+      f();
+
+      llvm_asm!("pop r0" :::: "volatile");
+      llvm_asm!("pop r1" :::: "volatile");
+      llvm_asm!("pop r2" :::: "volatile");
+      llvm_asm!("pop r3" :::: "volatile");
+      llvm_asm!("pop r4" :::: "volatile");
+      llvm_asm!("pop r5" :::: "volatile");
+      llvm_asm!("pop r6" :::: "volatile");
+      llvm_asm!("pop r7" :::: "volatile");
+      llvm_asm!("pop r8" :::: "volatile");
+      llvm_asm!("pop r9" :::: "volatile");
+      llvm_asm!("pop r10" :::: "volatile");
+      llvm_asm!("pop r11" :::: "volatile");
+      llvm_asm!("pop r12" :::: "volatile");
+      llvm_asm!("pop r13" :::: "volatile");
+      llvm_asm!("pop r14" :::: "volatile");
+      llvm_asm!("pop r15" :::: "volatile");
+      llvm_asm!("pop r16" :::: "volatile");
+      llvm_asm!("pop r17" :::: "volatile");
+      llvm_asm!("pop r18" :::: "volatile");
+      llvm_asm!("pop r19" :::: "volatile");
+      llvm_asm!("pop r20" :::: "volatile");
+      llvm_asm!("pop r21" :::: "volatile");
+      llvm_asm!("pop r22" :::: "volatile");
+      llvm_asm!("pop r23" :::: "volatile");
+
+      llvm_asm!("pop r25" :::: "volatile");
+      llvm_asm!("pop r26" :::: "volatile");
+      llvm_asm!("pop r27" :::: "volatile");
+      llvm_asm!("pop r28" :::: "volatile");
+      llvm_asm!("pop r29" :::: "volatile");
+      llvm_asm!("pop r30" :::: "volatile");
+      llvm_asm!("pop r31" :::: "volatile");
+
+      llvm_asm!("pop r24" :::: "volatile");
+      #[cfg(feature="atmega4809")]
+      llvm_asm!("out 0x0F,r24" :::: "volatile");
+      #[cfg(feature="atmega328p")]
+      llvm_asm!("out 0x3F,r24" :::: "volatile");
+      llvm_asm!("pop r24" :::: "volatile");
+    }
   }
 
   #[cfg(not(target_arch="avr"))]
@@ -229,7 +315,7 @@ pub mod interrupt {
   pub(crate) unsafe fn disable_interrupts() {
   }
 
-  use avr_oxide::hal::generic::debugled::DebugLed;
+
   #[cfg(target_arch="avr")]
   #[inline(always)]
   pub(crate) unsafe fn enable_interrupts(){
