@@ -38,12 +38,12 @@ pub enum IsrCallback<F,R>
 macro_rules! isr_cb_invoke {
   ($cb:expr, $($params:expr),*) => {
     {
-      let cb : crate::hal::generic::callback::IsrCallback<_,_> = $cb;
+      let cb : avr_oxide::hal::generic::callback::IsrCallback<_,_> = $cb;
 
       match cb {
-        crate::hal::generic::callback::IsrCallback::Nop(r) => r,
-        crate::hal::generic::callback::IsrCallback::Function(f) => (f)($($params),*, Option::None),
-        crate::hal::generic::callback::IsrCallback::WithData(f,d) => (f)($($params),*, Option::Some(d))
+        avr_oxide::hal::generic::callback::IsrCallback::Nop(r) => r,
+        avr_oxide::hal::generic::callback::IsrCallback::Function(f) => (f)($($params),*, Option::None),
+        avr_oxide::hal::generic::callback::IsrCallback::WithData(f,d) => (f)($($params),*, Option::Some(d))
       }
     }
   }
