@@ -17,7 +17,7 @@ pub mod eeprom;
 
 #[allow(unused_assignments)]
 #[cfg(target_arch="avr")]
-pub(in crate) fn busy_loop(mut c: u16) {
+pub fn busy_loop(mut c: u16) {
   unsafe {
     #![allow(deprecated)] // until asm! is implemented for AVR
     llvm_asm!("1: sbiw $0,1\n\tbrne 1b"
