@@ -117,6 +117,7 @@ where
 #[cfg(target_arch="avr")]
 pub mod base {
   use avr_oxide::hal::generic::port::InterruptMode;
+  use avr_oxide::{v_read, v_write};
 
   pub trait AtmelPortControl {
     /// Set this pin as an output.
@@ -141,6 +142,9 @@ pub mod base {
     fn interrupted(&self, p: u8) -> bool;
     /// Clear the interrupt flag for all pins on this port
     fn clear_interrupts(&mut self);
+    /// Return a tuple (pin,state) of pins generating an interrupt.  Called
+    /// from the ISR, so make it quick.
+    fn isr_get_interrupting_pins(&mut self)->(u8,u8);
   }
 
   impl InterruptMode {
@@ -184,6 +188,16 @@ pub mod base {
     pub(crate) pinctrl: [u8; 8]
   }
 
+  /**
+   * The older ATmegas like the '328P have a much simpler port control
+   * block (if you can even call it that...)
+   */
+  #[repr(C)]
+  pub struct AvrSimplePortRegisterBlock<const PCIEN: u16, const PCICR: u16, const PCIFR: u16, const PCICRMASK: u8> {
+    pub(crate) pin: u8,
+    pub(crate) ddr: u8,
+    pub(crate) port: u8
+  }
 
 
   impl AtmelPortControl for AvrPortRegisterBlock {
@@ -270,19 +284,140 @@ pub mod base {
         core::ptr::write_volatile(&mut self.intflags as *mut u8, 0xff);
       }
     }
+
+    #[inline(always)]
+    fn isr_get_interrupting_pins(&mut self) -> (u8,u8) {
+      unsafe {
+        let intflags:u8 = v_read!(u8, self.intflags);
+        let state:u8    = v_read!(u8, self.inp);
+
+        (intflags,state)
+      }
+    }
+  }
+
+  impl<const PCIEN: u16, const PCICR: u16, const PCIFR:u16,  const PCICRMASK: u8> AtmelPortControl for AvrSimplePortRegisterBlock<PCIEN,PCICR,PCIFR,PCICRMASK> {
+    fn enable_output(&mut self, p: u8) {
+      unsafe {
+        v_write!(u8, self.ddr, v_read!(u8, self.ddr) | 0x01 << p);
+      }
+    }
+
+    fn disable_output(&mut self, p: u8) {
+      unsafe {
+        v_write!(u8, self.ddr, v_read!(u8, self.ddr) ^ 0x01 << p);
+      }
+    }
+
+    fn enable_pullup(&mut self, p: u8) {
+      unsafe {
+        v_write!(u8, self.port, v_read!(u8, self.port) | 0x01 << p);
+      }
+    }
+
+    fn disable_pullup(&mut self, p: u8) {
+      unsafe {
+        v_write!(u8, self.port, v_read!(u8, self.port) | 0x01 << p);
+      }
+    }
+
+    fn set_high(&mut self, p: u8) {
+      unsafe {
+        v_write!(u8, self.port, v_read!(u8, self.port) | 0x01 << p);
+      }
+    }
+
+    fn set_low(&mut self, p: u8) {
+      unsafe {
+        v_write!(u8, self.port, v_read!(u8, self.port) | 0x01 << p);
+      }
+    }
+
+    fn toggle(&mut self, p: u8) {
+      unsafe {
+        v_write!(u8, self.pin, 0x01 << p); // Writing 1 to the input toggles the output on '328p et al
+      }
+    }
+
+    fn get(&self, p: u8) -> bool {
+      unsafe {
+        v_read!(u8, self.pin) & (0x01 << p) > 0
+      }
+    }
+
+    fn set_interrupt_mode(&mut self, p: u8, mode: InterruptMode) {
+      unsafe {
+        let pcien = &mut *(PCIEN as *mut u8);
+        let pcicr = &mut *(PCICR as *mut u8);
+
+        match mode {
+          // @todo actually change the global level/edge mode
+          InterruptMode::Disabled => {
+            v_write!(u8, *pcien, v_read!(u8, *pcien) ^ 0x01 << p);
+          }
+          InterruptMode::BothEdges => {
+            v_write!(u8, *pcicr, v_read!(u8, *pcicr) | PCICRMASK);
+            v_write!(u8, *pcien, v_read!(u8, *pcien) | 0x01 << p);
+          },
+          InterruptMode::RisingEdge => {
+            v_write!(u8, *pcicr, v_read!(u8, *pcicr) | PCICRMASK);
+            v_write!(u8, *pcien, v_read!(u8, *pcien) | 0x01 << p);
+          },
+          InterruptMode::FallingEdge => {
+            v_write!(u8, *pcicr, v_read!(u8, *pcicr) | PCICRMASK);
+            v_write!(u8, *pcien, v_read!(u8, *pcien) | 0x01 << p);
+          },
+          InterruptMode::LowLevel => {
+            v_write!(u8, *pcicr, v_read!(u8, *pcicr) | PCICRMASK);
+            v_write!(u8, *pcien, v_read!(u8, *pcien) | 0x01 << p);
+          }
+        }
+      }
+    }
+
+    /**
+     * Indicate if a pin generated an interrupt.  We can't actually tell, so
+     * we're just gonna say yes for all of them.
+     */
+    fn interrupted(&self, _p: u8) -> bool {
+      true
+    }
+
+    /**
+     * Clear interrupts.  We don't actually need to do this on the '328 because
+     * they are cleared automatically when the ISR completes, but no harm done
+     * by forcing the issue.
+     */
+    fn clear_interrupts(&mut self) {
+      unsafe {
+        let pcifr = &mut *(PCIFR as *mut u8);
+
+        v_write!(u8, *pcifr, PCICRMASK)
+      }
+    }
+
+    /**
+     * Indicate which pin generated an interrupt.  Unfortunately the '328
+     * doesn't make this easy for us, so we just say "all of 'em".
+     */
+    fn isr_get_interrupting_pins(&mut self) -> ( u8, u8 ) {
+      unsafe {
+        ( 0xff, v_read!(u8, self.pin) )
+      }
+    }
   }
 
   #[doc(hidden)]
   #[macro_export]
   macro_rules! atmel_port_tpl {
-    ($ref:expr, $portsrc:expr, $isr:ident) => {
+    ($ref:expr, $portsrc:expr, $implementation:ty, $isr:ident) => {
       use core::any::Any;
 
       use avr_oxide::hal::generic::port::{PinMode,Pin,PinIdentity,InterruptMode,PinIsrCallback};
-      use avr_oxide::hal::generic::port::base::{AtmelPortControl,AvrPortRegisterBlock};
+      use avr_oxide::hal::generic::port::base::{AtmelPortControl};
       use avr_oxide::isr_cb_invoke;
 
-      pub type PortImpl = AvrPortRegisterBlock;
+      pub type PortImpl = $implementation;
       pub type PinImpl = AtmelPin;
 
       /**
@@ -358,7 +493,7 @@ pub mod base {
        * called.
        */
       #[inline(always)]
-      pub fn instance() -> &'static mut AvrPortRegisterBlock  {
+      pub fn instance() -> &'static mut $implementation  {
         unsafe {
           // Not sure if this is a compiler bug or what, but our static
           // muts don't seem to be correctly initialised, so we need to
@@ -406,8 +541,8 @@ pub mod base {
       #[no_mangle]
       pub unsafe extern "avr-interrupt" fn $isr() {
         avr_oxide::hal::concurrency::interrupt::isr(||{
-          let intflags:u8 = core::ptr::read_volatile(&instance().intflags as *const u8);
-          let state:u8    = core::ptr::read_volatile(&instance().inp as *const u8);
+          let (intflags, state) = instance().isr_get_interrupting_pins();
+
           let mut mask    = 0x01;
 
           for pin in 0..=7 {
@@ -416,6 +551,7 @@ pub mod base {
             }
             mask <<= 1;
           }
+
           instance().clear_interrupts();
         })
       }
@@ -531,7 +667,7 @@ pub mod base {
   #[doc(hidden)]
   #[macro_export]
   macro_rules! atmel_port_tpl {
-    ($ref:expr, $portsrc:expr, $isr:ident) => {
+    ($ref:expr, $portsrc:expr, $implementation:ty, $isr:ident) => {
       use core::any::Any;
 
       use avr_oxide::hal::generic::port::{PinMode,Pin,PinIdentity,InterruptMode,PinIsrCallback};
