@@ -9,7 +9,7 @@
 use core::any::Any;
 use ufmt::derive::uDebug;
 use oxide_macros::Persist;
-use crate::hal::generic::callback::IsrCallback;
+use avr_oxide::hal::generic::callback::IsrCallback;
 
 // Declarations ==============================================================
 #[derive(Clone,Copy)]
@@ -132,8 +132,8 @@ pub trait RtcTimerCalibration {
 #[cfg(target_arch="avr")]
 pub mod base {
   use core::cell::{Cell, RefCell};
-  use crate::hal::generic::timer::{TimerIsrCallback, TimerMode, TimerControl, TimerIdentity, RtcTimerCalibration, RtcSource, RtcCalibration, RtcPrescaler};
-  use crate::{isr_cb_invoke, v_read, v_write};
+  use avr_oxide::hal::generic::timer::{TimerIsrCallback, TimerMode, TimerControl, TimerIdentity, RtcTimerCalibration, RtcSource, RtcCalibration, RtcPrescaler};
+  use avr_oxide::{isr_cb_invoke, v_read, v_write};
 
   #[repr(C)]
   pub struct AvrTypeBTimerControl {
@@ -260,7 +260,7 @@ pub mod base {
 
       tcb.clear_interrupt();
 
-      crate::hal::concurrency::interrupt::isolated(||{
+      avr_oxide::hal::concurrency::interrupt::isolated(||{
         self.interrupt_handler.replace(handler);
       });
       if handler.is_nop() {
@@ -317,10 +317,10 @@ pub mod base {
   #[macro_export]
   macro_rules! atmel_tcb {
     ($tcbref:expr, $timersrc:expr, $isr:ident) => {
-      use crate::hal::generic::timer::{ TimerMode, TimerIsrCallback };
-      use crate::hal::generic::timer::base::{ AtmelTimer, AtmelTCB, AvrTypeBTimerControl };
+      use avr_oxide::hal::generic::timer::{ TimerMode, TimerIsrCallback };
+      use avr_oxide::hal::generic::timer::base::{ AtmelTimer, AtmelTCB, AvrTypeBTimerControl };
 
-      use crate::mut_singleton;
+      use avr_oxide::mut_singleton;
       use core::cell::{RefCell,Cell};
 
 
@@ -343,7 +343,7 @@ pub mod base {
       pub unsafe extern "avr-interrupt" fn $isr() {
         static mut COUNT_INTS : u16 = 0;
 
-        crate::hal::concurrency::interrupt::isr(||{
+        avr_oxide::hal::concurrency::interrupt::isr(||{
           let counter = core::ptr::read_volatile(&COUNT_INTS as *const u16);
 
           match &mut INSTANCE {
@@ -511,7 +511,7 @@ pub mod base {
         while (v_read!(u8, rtc.status) & 0x01) != 0 {}
 
         // Set interrupt handler and enable if necessary
-        crate::hal::concurrency::interrupt::isolated(||{
+        avr_oxide::hal::concurrency::interrupt::isolated(||{
           self.interrupt_handler.replace(handler);
         });
         if handler.is_nop() {
@@ -583,10 +583,10 @@ pub mod base {
   #[macro_export]
   macro_rules! atmel_rtc {
     ($rtcref:expr, $timersrc:expr, $isr: ident) => {
-      use crate::hal::generic::timer::{ TimerMode, TimerIsrCallback };
-      use crate::hal::generic::timer::base::{ AvrRealTimeCounterControl, AvrRealTimeCounter, RtcPitPeriod };
+      use avr_oxide::hal::generic::timer::{ TimerMode, TimerIsrCallback };
+      use avr_oxide::hal::generic::timer::base::{ AvrRealTimeCounterControl, AvrRealTimeCounter, RtcPitPeriod };
 
-      use crate::mut_singleton;
+      use avr_oxide::mut_singleton;
       use core::cell::{RefCell,Cell};
 
       pub type TimerImpl = AvrRealTimeCounter;
@@ -604,7 +604,7 @@ pub mod base {
 
       #[no_mangle]
       pub unsafe extern "avr-interrupt" fn $isr() {
-        crate::hal::concurrency::interrupt::isr(||{
+        avr_oxide::hal::concurrency::interrupt::isr(||{
           match &mut INSTANCE {
             None => {},
             Some(avrrtc) => {
@@ -620,8 +620,8 @@ pub mod base {
 
 #[cfg(not(target_arch="avr"))]
 pub mod base {
-  use crate::hal::generic::timer::{TimerIsrCallback, TimerMode, TimerControl, TimerIdentity, RtcTimerCalibration, RtcSource, RtcCalibration, RtcPrescaler};
-  use crate::isr_cb_invoke;
+  use avr_oxide::hal::generic::timer::{TimerIsrCallback, TimerMode, TimerControl, TimerIdentity, RtcTimerCalibration, RtcSource, RtcCalibration, RtcPrescaler};
+  use avr_oxide::isr_cb_invoke;
 
   #[repr(C)]
   pub struct DummyTypeBTimerControl {
@@ -737,8 +737,8 @@ pub mod base {
   #[macro_export]
   macro_rules! atmel_tcb {
     ($tcbref:expr, $timersrc:expr, $isr:ident) => {
-      use crate::hal::generic::timer::{ TimerMode, TimerIsrCallback };
-      use crate::hal::generic::timer::base::{ DummyTimer, DummyTypeBTimerControl };
+      use avr_oxide::hal::generic::timer::{ TimerMode, TimerIsrCallback };
+      use avr_oxide::hal::generic::timer::base::{ DummyTimer, DummyTypeBTimerControl };
 
       pub type TimerImpl = DummyTimer<DummyTypeBTimerControl>;
 
@@ -857,10 +857,10 @@ pub mod base {
   #[macro_export]
   macro_rules! atmel_rtc {
     ($rtcref:expr, $timersrc:expr, $isr: ident) => {
-      use crate::hal::generic::timer::{ TimerMode, TimerIsrCallback };
-      use crate::hal::generic::timer::base::{ DummyRealTimeCounter, RtcPitPeriod };
+      use avr_oxide::hal::generic::timer::{ TimerMode, TimerIsrCallback };
+      use avr_oxide::hal::generic::timer::base::{ DummyRealTimeCounter, RtcPitPeriod };
 
-      use crate::mut_singleton;
+      use avr_oxide::mut_singleton;
 
       pub type TimerImpl = DummyRealTimeCounter;
 
