@@ -12,4 +12,6 @@ pub mod concurrency;
 #[cfg(feature="atmega4809")]
 pub mod atmega4809;
 
+#[cfg(feature="atmega328p")]
+pub mod atmega328p;
 
