@@ -22,7 +22,7 @@ macro_rules! mut_singleton {
     pub fn $accessor() -> &'static mut $type {
       unsafe {
 
-        crate::hal::concurrency::interrupt::isolated(||{
+        avr_oxide::hal::concurrency::interrupt::isolated(||{
           if $name.is_none() {
             core::ptr::replace(&mut $name, Some($constructor));
           }
