@@ -114,10 +114,10 @@
 
 // Imports ===================================================================
 use avr_oxide::devices::internal::StaticShareable;
-use crate::devices::Handle;
-use crate::private::ringq::RingQ;
-use crate::event::{OxideEvent, EventSink, EventSource, OxideEventEnvelope};
-use crate::hal::concurrency::interrupt;
+use avr_oxide::devices::Handle;
+use avr_oxide::private::ringq::RingQ;
+use avr_oxide::event::{OxideEvent, EventSink, EventSource, OxideEventEnvelope};
+use avr_oxide::hal::concurrency::interrupt;
 
 // Declarations ==============================================================
 
