@@ -259,4 +259,16 @@ mod tests {
     first += second;
     assert_eq!(first, Duration::from_secs(34));
   }
+
+  #[test]
+  fn test_32bit_increment(){
+    let mut timestamp = Duration::from_secs(0);
+    let one = Duration::from_secs(1);
+
+    for i in 1..u32::MAX {
+      timestamp += one;
+
+      assert_eq!(timestamp.as_secs(), i);
+    }
+  }
 }
\ No newline at end of file
